# Generated by Django 2.2.19 on 2021-02-26 07:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_site_warnings', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='waringcategory',
            name='code',
            field=models.CharField(max_length=255, unique=True, verbose_name='Warning Category Code'),
        ),
        migrations.AlterField(
            model_name='waringcategory',
            name='name',
            field=models.CharField(max_length=255, verbose_name='Warning Category Name'),
        ),
    ]
