# Generated by Django 2.2.27 on 2022-03-10 07:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_site_warnings', '0004_auto_20210304_2119'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='warning',
            name='active',
        ),
        migrations.RemoveField(
            model_name='warning',
            name='error_code',
        ),
        migrations.RemoveField(
            model_name='warning',
            name='error_message',
        ),
        migrations.RemoveField(
            model_name='warning',
            name='expire_time',
        ),
        migrations.RemoveField(
            model_name='warning',
            name='ready_time',
        ),
        migrations.RemoveField(
            model_name='warning',
            name='result',
        ),
        migrations.RemoveField(
            model_name='warning',
            name='worker',
        ),
        migrations.AddField(
            model_name='warning',
            name='auto_reset_time',
            field=models.DateTimeField(blank=True, editable=False, help_text='After which time the task should be reset.', null=True, verbose_name='Auto Reset Time'),
        ),
        migrations.AddField(
            model_name='warning',
            name='current_step',
            field=models.IntegerField(blank=True, editable=False, null=True, verbose_name='Current Step'),
        ),
        migrations.AddField(
            model_name='warning',
            name='step1_time',
            field=models.DateTimeField(blank=True, editable=False, null=True, verbose_name='Step1 start time'),
        ),
        migrations.AddField(
            model_name='warning',
            name='step2_time',
            field=models.DateTimeField(blank=True, editable=False, null=True, verbose_name='Step2 start time'),
        ),
        migrations.AddField(
            model_name='warning',
            name='step3_time',
            field=models.DateTimeField(blank=True, editable=False, null=True, verbose_name='Step3 start time'),
        ),
        migrations.AlterField(
            model_name='warning',
            name='add_time',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Add Time'),
        ),
        migrations.AlterField(
            model_name='warning',
            name='done_time',
            field=models.DateTimeField(blank=True, editable=False, null=True, verbose_name='Done Time'),
        ),
        migrations.AlterField(
            model_name='warning',
            name='mod_time',
            field=models.DateTimeField(auto_now=True, verbose_name='Modify Time'),
        ),
        migrations.AlterField(
            model_name='warning',
            name='start_time',
            field=models.DateTimeField(blank=True, editable=False, null=True, verbose_name='Start Time'),
        ),
        migrations.AlterField(
            model_name='warning',
            name='status',
            field=models.IntegerField(choices=[(10, 'Ready'), (20, 'Doing'), (30, 'Done')], default=10, editable=False, verbose_name='Status'),
        ),
        migrations.AlterField(
            model_name='warning',
            name='success',
            field=models.NullBooleanField(editable=False, verbose_name='Success Status'),
        ),
    ]
