# Generated by Django 2.2.19 on 2021-03-04 13:19

from django.db import migrations
import django_safe_fields.fields


class Migration(migrations.Migration):

    dependencies = [
        ('django_site_warnings', '0003_auto_20210226_1617'),
    ]

    operations = [
        migrations.AlterField(
            model_name='warning',
            name='title',
            field=django_safe_fields.fields.SafeCharField(max_length=1024, verbose_name='Warning Title'),
        ),
    ]
