# Generated by Django 2.2.19 on 2021-02-26 08:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_site_warnings', '0002_auto_20210226_1541'),
    ]

    operations = [
        migrations.AddField(
            model_name='warning',
            name='ack',
            field=models.BooleanField(default=False, verbose_name='Acknowledged'),
        ),
        migrations.AddField(
            model_name='warning',
            name='ack_time',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Acknowledged Time'),
        ),
    ]
